Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(252)

Unified Diff: extensions/common/file_util.h

Issue 2686463003: [Extensions] Fix a data race in ChromeExtensionMessageFilter. (Closed)
Patch Set: [Extensions] Fix a data race in ChromeExtensionMessageFilter. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: extensions/common/file_util.h
diff --git a/extensions/common/file_util.h b/extensions/common/file_util.h
index bc080edb546ba59b0295c487732d38eded0a40e4..221e86f13972ff3ef9209b17ffeb6bee53f689ed 100644
--- a/extensions/common/file_util.h
+++ b/extensions/common/file_util.h
@@ -23,7 +23,6 @@ class FilePath;
namespace extensions {
class Extension;
-class ExtensionSet;
struct InstallWarning;
// Utilities for manipulating the on-disk storage of extensions.
@@ -135,12 +134,17 @@ MessageBundle::SubstitutionMap* LoadMessageBundleSubstitutionMap(
const std::string& extension_id,
const std::string& default_locale);
-// Loads the extension message bundle substitution map, including messages from
-// Shared Modules that the given extension imports. Contains at least the
-// extension_id item.
-MessageBundle::SubstitutionMap* LoadMessageBundleSubstitutionMapWithImports(
+// Loads the extension message bundle substitution map for a non-localized
+// extension. Contains only the extension_id item.
Devlin 2017/02/16 16:20:56 nit: let's expand this a little to include: // Thi
atuchin 2017/02/17 06:22:02 Done.
+MessageBundle::SubstitutionMap* LoadNonLocalizedMessageBundleSubstitutionMap(
+ const std::string& extension_id);
+
+// Loads the extension message bundle substitution map from the specified paths.
+// Contains at least the extension_id item.
+MessageBundle::SubstitutionMap* LoadMessageBundleSubstitutionMapFromPaths(
+ const std::vector<base::FilePath>& paths,
const std::string& extension_id,
- const ExtensionSet& extension_set);
+ const std::string& default_locale);
// Helper functions for getting paths for files used in content verification.
base::FilePath GetVerifiedContentsPath(const base::FilePath& extension_path);

Powered by Google App Engine
This is Rietveld 408576698